from distutils.core import setup

setup(
    name='ETemplator',
    version='0.1',
    packages=['templator'],
    url='http://amitbhat.in',
    license='MIT',
    author='amit',
    author_email='amit.bhat@outlook.com',
    description='App for creating/populating email templates'
)
